@@ -15,7 +15,7 @@ class StreamLoader(Loader):
     # Read
 
     def read_byte_stream_create(self):
-        source = self.file.source
+        source = self.resource.source
         if hasattr(source, "encoding"):
             error = errors.SchemeError(note="only byte streams are supported")
             raise exceptions.FrictionlessException(error)
